@@ -26,6 +26,9 @@ FAILEDOPERATION_AGENOTACHIEVENORMALLEGAL = 'FailedOperation.AgeNotAchieveNormalL
 # 鉴权失败。
 FAILEDOPERATION_AUTHFAIL = 'FailedOperation.AuthFail'
 
+# 当选择“企业实名认证（信任第三方认证源）”时，请先使用“同步企业信息”接口，同步企业名称、统一社会信用代码、法人姓名。
+FAILEDOPERATION_ERRNOTSYNCPROXYORGANIZATION = 'FailedOperation.ErrNotSyncProxyOrganization'
+
 # 存在同名印章。
 FAILEDOPERATION_EXISTSAMESEALNAME = 'FailedOperation.ExistSameSealName'
 
@@ -254,7 +257,7 @@ INVALIDPARAMETER_RESOURCETYPE = 'InvalidParameter.ResourceType'
 # 角色ID不正确
 INVALIDPARAMETER_ROLEID = 'InvalidParameter.RoleId'
 
-# 文件内容敏感信息。
+# 上传的文件包含敏感（不合规）的内容，请确认。
 INVALIDPARAMETER_SENSITIVEFILECONTENT = 'InvalidParameter.SensitiveFileContent'
 
 # 参数错误，不合法的签署控件类型，请修改后重试。
@@ -281,6 +284,12 @@ INVALIDPARAMETER_FFOWIDS = 'InvalidParameter.fFowIds'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 非法的套餐类型
+INVALIDPARAMETERVALUE_INVALIDQUOTATYPE = 'InvalidParameterValue.InvalidQuotaType'
+
+# 非法的时间参数
+INVALIDPARAMETERVALUE_INVALIDTIME = 'InvalidParameterValue.InvalidTime'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -362,6 +371,9 @@ MISSINGPARAMETER_USEROPENID = 'MissingParameter.UserOpenId'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 相关资源已经存证, 无法在创建新的相关资源
+OPERATIONDENIED_ALREADYHAS = 'OperationDenied.AlreadyHas'
+
 # 参与人信息有重复
 OPERATIONDENIED_APPROVERREPEAT = 'OperationDenied.ApproverRepeat'
 
@@ -380,6 +392,9 @@ OPERATIONDENIED_DOWNLOADMORETHANONE = 'OperationDenied.DownLoadMoreThanOne'
 # 无资源访问权限。
 OPERATIONDENIED_ERRNORESOURCEACCESS = 'OperationDenied.ErrNoResourceAccess'
 
+# 第三方应用平台未开通“平台子客企业实名认证（信任第三方认证源）”能力
+OPERATIONDENIED_ERRNOTOPENWEAKAUTHORIZATION = 'OperationDenied.ErrNotOpenWeakAuthorization'
+
 # 文件已删除。
 OPERATIONDENIED_FILEDELETED = 'OperationDenied.FileDeleted'
 
@@ -416,6 +431,9 @@ OPERATIONDENIED_NOQUOTA = 'OperationDenied.NoQuota'
 # 不属于企业超管或者法人。
 OPERATIONDENIED_NOTBELONGSUPERADMINORLEGALPERSON = 'OperationDenied.NotBelongSuperAdminOrLegalPerson'
 
+# 不支持的企业类型
+OPERATIONDENIED_NOTSUPPORTORGTYPE = 'OperationDenied.NotSupportOrgType'
+
 # 操作类型不支持。
 OPERATIONDENIED_OPERATETYPE = 'OperationDenied.OperateType'
 
@@ -470,6 +488,9 @@ RESOURCENOTFOUND_FLOWAPPROVERS = 'ResourceNotFound.FlowApprovers'
 # 合同组不存在。
 RESOURCENOTFOUND_FLOWGROUP = 'ResourceNotFound.FlowGroup'
 
+# 应用号不存在
+RESOURCENOTFOUND_NOTEXISTAPPLICATION = 'ResourceNotFound.NotExistApplication'
+
 # 机构不存在。
 RESOURCENOTFOUND_ORGANIZATION = 'ResourceNotFound.Organization'
 
